OC.L10N.register(
    "comments",
    {
    "<strong>Comments</strong> for files" : "<strong>Комментарии</strong> к файлам",
    "%1$s commented" : "%1$s откомментировано",
    "%1$s commented on %2$s" : "%1$s откомментировано на %2$s",
    "Comments" : "Коментарии",
    "Type in a new comment..." : "Запишите новый комментарий...",
    "Delete comment" : "Удалить комментарий",
    "Post" : "Запись",
    "Cancel" : "Отмена",
    "Edit comment" : "Редактировать комментарий",
    "[Deleted user]" : "[Удалённый пользователь]",
    "No other comments available" : "Нет других комментариев",
    "More comments..." : "Ещё комментарии...",
    "Save" : "Сохранить",
    "Allowed characters {count} of {max}" : "Допустимых символов {count} из {max}",
    "{count} unread comments" : "{count} непрочитанных комментариев",
    "Comment" : "Коментарий",
    "<strong>Comments</strong> for files" : "<strong>Комментарии</strong> к файлам"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
